'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-1115561c.js');
const store = require('./store-49c65768.js');

const iconContent = new Map();
const requests = new Map();
function getSvgContent(url) {
    // see if we already have a request for this url
    let request = requests.get(url);
    if (!request) {
        // we don't already have a request
        request = fetch(url).then((response) => {
            if (response.ok) {
                return response.text().then((svgContent) => {
                    iconContent.set(url, svgContent);
                    return svgContent;
                });
            }
            iconContent.set(url, "");
        });
        // cache for the same requests
        requests.set(url, request);
    }
    return request;
}

const iconCss = ":host(:not([auto-color])){}:host(:not([auto-color])) svg *{fill:var(--icon-color) !important}:host(:not([auto-color])) path.icons01{fill:var(--icons01-enabled)}:host(:not([auto-color])) path.icons02{fill:var(--icons02-enabled)}:host(:not([auto-color])) path.icons03{fill:var(--icons03-enabled)}:host(:not([auto-color])) path.icons04{fill:var(--icons04-enabled)}:host(:not([auto-color])) path.icons05{fill:var(--icons05-enabled)}:host(:not([auto-color])) path.icons06{fill:var(--icons06-enabled)}:host(:not([auto-color])) path.icons07{fill:var(--icons07-enabled)}:host(:not([auto-color])) path.icons08{fill:var(--icons08-enabled)}:host(:not([auto-color])) path.icons09{fill:var(--icons09-enabled)}:host{display:-ms-inline-flexbox;display:inline-flex;line-height:0}:host svg{width:var(--icon-size);height:var(--icon-size)}";

const ChIcon = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /*********************************
        PROPERTIES & STATE
        *********************************/
        /**
         * If enabled, the icon will be loaded lazily when it's visible in the viewport.
         */
        this.lazy = false;
        /**
         * If enabled, the icon will display its inherent/natural color
         */
        this.autoColor = false;
        /**
         * The URL of the icon.
         */
        this.src = "";
        this.isVisible = false;
    }
    /*********************************
    METHODS
    *********************************/
    connectedCallback() {
        // purposely do not return the promise here because loading
        // the svg file should not hold up loading the app
        // only load the svg if it's visible
        this.waitUntilVisible(this.element, "50px", () => {
            this.isVisible = true;
            this.getIcon();
        });
    }
    disconnectedCallback() {
        if (this.io !== undefined) {
            this.io.disconnect();
            this.io = undefined;
        }
    }
    waitUntilVisible(el, rootMargin, callback) {
        if (this.lazy &&
            typeof window !== "undefined" &&
            window.IntersectionObserver) {
            const io = (this.io = new window.IntersectionObserver((data) => {
                if (data[0].isIntersecting) {
                    io.disconnect();
                    this.io = undefined;
                    callback();
                }
            }, { rootMargin }));
            io.observe(el);
        }
        else {
            // browser doesn't support IntersectionObserver
            // so just fallback to always show it
            callback();
        }
    }
    async getIcon() {
        if (this.isVisible) {
            if (this.src) {
                if (iconContent.has(this.src)) {
                    this.svgContent = iconContent.get(this.src);
                }
                else {
                    this.svgContent = await getSvgContent(this.src);
                }
            }
            else {
                this.svgContent = "";
                return;
            }
        }
    }
    render() {
        return index.h("div", { innerHTML: this.svgContent });
    }
    static get assetsDirs() { return ["ch-icon-assets"]; }
    get element() { return index.getElement(this); }
    static get watchers() { return {
        "src": ["getIcon"]
    }; }
};
ChIcon.style = iconCss;

const buttonCss = "/*! normalize.css v8.0.1 | MIT License | github.com/necolas/normalize.css */html{line-height:1.15;-webkit-text-size-adjust:100%;}body{margin:0}main{display:block}h1{font-size:2em;margin:0.67em 0}hr{-webkit-box-sizing:content-box;box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace, monospace;font-size:1em;}a{background-color:transparent}abbr[title]{border-bottom:none;text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted;}b,strong{font-weight:bolder}code,kbd,samp{font-family:monospace, monospace;font-size:1em;}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-0.25em}sup{top:-0.5em}img{border-style:none}button,input,optgroup,select,textarea{font-family:inherit;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible}button,select{text-transform:none}button,[type=button],[type=reset],[type=submit]{-webkit-appearance:button}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText}fieldset{padding:0.35em 0.75em 0.625em}legend{-webkit-box-sizing:border-box;box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{vertical-align:baseline}textarea{overflow:auto}[type=checkbox],[type=radio]{-webkit-box-sizing:border-box;box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto}[type=search]{-webkit-appearance:textfield;outline-offset:-2px;}[type=search]::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit;}details{display:block}summary{display:list-item}template{display:none}[hidden]{display:none}:root{--ui-animaton-speed:0.2s}.gxg-title-01{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-title-01--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-title-02{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em}.gxg-title-02--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em;color:var(--color-on-primary)}.gxg-title-03{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-xs);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em}.gxg-title-03--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-xs);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em;color:var(--color-on-primary)}.gxg-title-04{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-title-04--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-title-05{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;line-height:1.556em}.gxg-title-05--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;line-height:1.556em;color:var(--color-on-primary)}.gxg-text{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-text--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-text--gray{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--gray-05)}.gxg-quote{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;font-style:italic}.gxg-quote--negative{color:var(--color-on-primary)}.gxg-link{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block}.gxg-link:hover{color:var(--color-primary-hover)}.gxg-link:active{color:var(--color-primary-active)}.gxg-link-gray{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block;color:var(--gray-04)}.gxg-link-gray:hover{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block;color:var(--gray-04);color:var(--gray-06)}.gxg-alert-error{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-error-dark);display:inline-block}.gxg-alert-warning{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-warning-dark);display:inline-block}.gxg-alert-success{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-success-dark);display:inline-block}.gxg-tab--disabled{color:var(--color-primary-disabled);pointer-events:none}.gxg-tab--disabled[disabled]{color:var(--color-primary-disabled);pointer-events:none}.gxg-label{font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em}.gxg-label:hover{color:var(--color-primary-hover)}.gxg-label:focud{color:var(--color-primary-active)}.gxg-label:active{color:var(--color-primary-active)}.gxg-label[disabled]{color:var(--color-primary-disabled)}.gxg-label--negative{color:var(--color-on-primary)}.gxg-label--negative[disabled]{color:var(--color-on-disabled)}.gxg-button-styles{font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em}:host{display:inline-block;line-height:0;position:relative}:host .ghost-icon{width:0}:host(.button) .button-native{--svg-icon-regular-scale:var(\n    --svg-icon-small-scale\n  );height:20px;position:relative;font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em;background:var(--color-primary-enabled);border:0;-webkit-box-shadow:inset 0px 0px 0px 1px transparent;box-shadow:inset 0px 0px 0px 1px transparent;border-radius:var(--border-radius-xs);display:-ms-inline-flexbox;display:inline-flex;-ms-flex-align:center;align-items:center;-ms-flex-pack:center;justify-content:center;padding-top:2.5px;padding-right:var(--spacing-comp-03);padding-bottom:2.5px;padding-left:var(--spacing-comp-03);line-height:var(--line-height-regular);-webkit-transition:background var(--ui-animaton-speed) ease, color var(--ui-animaton-speed) ease, -webkit-box-shadow var(--ui-animaton-speed) ease;transition:background var(--ui-animaton-speed) ease, color var(--ui-animaton-speed) ease, -webkit-box-shadow var(--ui-animaton-speed) ease;transition:background var(--ui-animaton-speed) ease, color var(--ui-animaton-speed) ease, box-shadow var(--ui-animaton-speed) ease;transition:background var(--ui-animaton-speed) ease, color var(--ui-animaton-speed) ease, box-shadow var(--ui-animaton-speed) ease, -webkit-box-shadow var(--ui-animaton-speed) ease;}:host(.button) .button-native:hover:not([disabled]){background:var(--color-primary-hover);cursor:pointer}:host(.button) .button-native:focus:not([disabled]){background:var(--color-primary-enabled);-webkit-box-shadow:var(--box-shadow-values) var(--color-primary-active);box-shadow:var(--box-shadow-values) var(--color-primary-active);outline:none}:host(.button) .button-native:active:not([disabled]){background:var(--color-primary-active)}:host(.button.button--disabled) .button-native{background:var(--color-primary-disabled);color:var(--color-primary-disabled);pointer-events:none}:host(.button.button--disabled){pointer-events:none}:host(.button--primary-text-only) .button-native{color:var(--color-on-primary);-webkit-padding-start:var(--spacing-comp-04);padding-inline-start:var(--spacing-comp-04);-webkit-padding-end:var(--spacing-comp-04);padding-inline-end:var(--spacing-comp-04)}:host(.button--primary-text-only.button--disabled) .button-native{color:var(--color-on-disabled)}:host(.button--primary-text-icon) .button-native{color:var(--color-on-primary);-webkit-padding-start:var(--spacing-comp-01);padding-inline-start:var(--spacing-comp-01);-webkit-padding-end:var(--spacing-comp-02);padding-inline-end:var(--spacing-comp-02)}:host(.button--primary-text-icon) .button-native gxg-icon:not(.ghost-icon){-webkit-padding-end:var(--spacing-comp-01);padding-inline-end:var(--spacing-comp-01)}:host(.button--primary-text-icon.button--disabled) .button-native{color:var(--color-on-disabled)}:host(.button--primary-icon-only) .button-native{background:var(--color-primary-enabled);color:var(--color-on-primary);width:20px;height:20px;padding-left:0;padding-right:0}:host(.button--primary-icon-only) .button-native:hover:not([disabled]){background:var(--color-primary-hover);color:var(--color-primary-hover)}:host(.button--primary-icon-only) .button-native:focus:not([disabled]){background:var(--color-primary-enabled);color:var(--color-primary-hover)}:host(.button--primary-icon-only) .button-native:active:not([disabled]){background:var(--color-primary-active);color:var(--color-on-primary)}:host(.button--primary-icon-only) .button-native:focus{outline:none}:host(.button--secondary-text-only) .button-native{background:transparent;-webkit-padding-start:var(--spacing-comp-04);padding-inline-start:var(--spacing-comp-04);-webkit-padding-end:var(--spacing-comp-04);padding-inline-end:var(--spacing-comp-04)}:host(.button--secondary-text-only) .button-native:hover:not([disabled]){color:var(--color-primary-hover);background:transparent}:host(.button--secondary-text-only) .button-native:focus:not([disabled]){color:var(--color-primary-active);background:transparent;-webkit-box-shadow:var(--box-shadow-values) var(--color-primary-active);box-shadow:var(--box-shadow-values) var(--color-primary-active)}:host(.button--secondary-text-only) .button-native:active:not([disabled]){color:var(--color-primary-active);-webkit-box-shadow:none;box-shadow:none}:host(.button--secondary-text-only) .button-native:focus{outline:none}:host(.button--secondary-text-only.button--disabled) .button-native{background:transparent;color:var(--color-primary-disabled)}:host(.button--secondary-text-icon) .button-native{background:transparent;-webkit-padding-start:0;padding-inline-start:0;-webkit-padding-start:var(--spacing-comp-01);padding-inline-start:var(--spacing-comp-01);-webkit-padding-end:var(--spacing-comp-02);padding-inline-end:var(--spacing-comp-02)}:host(.button--secondary-text-icon) .button-native gxg-icon:not(.ghost-icon){-webkit-padding-end:var(--spacing-comp-01);padding-inline-end:var(--spacing-comp-01)}:host(.button--secondary-text-icon) .button-native:hover:not([disabled]){color:var(--color-primary-hover);background:transparent}:host(.button--secondary-text-icon) .button-native:focus:not([disabled]){color:var(--color-primary-active);background:transparent;-webkit-box-shadow:var(--box-shadow-values) var(--color-primary-active);box-shadow:var(--box-shadow-values) var(--color-primary-active)}:host(.button--secondary-text-icon) .button-native:active:not([disabled]){color:var(--color-primary-active);-webkit-box-shadow:none;box-shadow:none}:host(.button--secondary-text-icon.button--disabled) .button-native{background:transparent;color:var(--color-primary-disabled)}:host(.button--secondary-text-icon.button--disabled) .button-native gxg-icon{--icon-color:var(--color-primary-disabled)}:host(.button--secondary-icon-only) .button-native{background:transparent;-webkit-padding-end:0;padding-inline-end:0;-webkit-padding-start:0;padding-inline-start:0;width:20px;height:20px}:host(.button--secondary-icon-only) .button-native:hover:not([disabled]){background:transparent}:host(.button--secondary-icon-only) .button-native:focus:not([disabled]){background:transparent;-webkit-box-shadow:var(--box-shadow-values) var(--color-primary-active);box-shadow:var(--box-shadow-values) var(--color-primary-active)}:host(.button--secondary-icon-only) .button-native:active:not([disabled]){background:transparent}:host(.button--secondary-icon-only.button--disabled) .button-native{background:transparent}:host(.button--outlined) .button-native{-webkit-box-shadow:inset 0px 0px 0px 1px var(--color-primary-enabled);box-shadow:inset 0px 0px 0px 1px var(--color-primary-enabled);background:var(--color-background);-webkit-padding-start:var(--spacing-comp-04);padding-inline-start:var(--spacing-comp-04);-webkit-padding-end:var(--spacing-comp-04);padding-inline-end:var(--spacing-comp-04)}:host(.button--outlined) .button-native:hover:not([disabled]){color:var(--color-primary-hover);background:var(--color-primary-hover-opacity-01);-webkit-box-shadow:inset 0px 0px 0px 1px var(--color-primary-hover);box-shadow:inset 0px 0px 0px 1px var(--color-primary-hover)}:host(.button--outlined) .button-native:focus:not([disabled]){color:var(--color-primary-active);background:transparent;-webkit-box-shadow:inset 0px 0px 0px 2px var(--color-primary-active);box-shadow:inset 0px 0px 0px 2px var(--color-primary-active)}:host(.button--outlined) .button-native:active:not([disabled]){color:var(--color-primary-active);background:transparent;-webkit-box-shadow:inset 0px 0px 0px 1px var(--color-primary-active);box-shadow:inset 0px 0px 0px 1px var(--color-primary-active)}:host(.button--outlined.button--disabled) .button-native{-webkit-box-shadow:inset 0px 0px 0px 1px var(--color-primary-disabled);box-shadow:inset 0px 0px 0px 1px var(--color-primary-disabled);background:var(--color-transparent);color:var(--color-primary-disabled)}:host(.button--tertiary) .button-native{background:transparent;-webkit-padding-end:0;padding-inline-end:0;-webkit-padding-start:0;padding-inline-start:0;height:20px;width:20px}:host(.button--tertiary) .button-native:hover:not([disabled]){background:transparent}:host(.button--tertiary) .button-native:hover:not([disabled]) gxg-icon{-webkit-transform:scale(0.75);transform:scale(0.75)}:host(.button--tertiary) .button-native:focus:not([disabled]){background:transparent;-webkit-box-shadow:var(--box-shadow-values) var(--color-primary-active);box-shadow:var(--box-shadow-values) var(--color-primary-active)}:host(.button--tertiary) .button-native:active:not([disabled]){background:transparent}:host(.button--tertiary.button--disabled) .button-native{background:transparent}:host(.button--fullwidth){width:100%}:host(.button--fullwidth) .button-native{width:100%}:host .icon-tooltip{position:absolute;border-width:0.5px;border-style:solid;border-color:var(--gray-04);color:var(--color-on-background);background-color:var(--gray-01);font-size:8px;font-weight:var(--font-weight-regular);font-family:var(--font-family-primary);padding:1px 5px;width:-webkit-max-content;width:-moz-max-content;width:max-content;left:0;top:20px;display:none;opacity:0;-webkit-transition-property:opacity;transition-property:opacity;-webkit-transition-duration:var(--ui-animaton-speed);transition-duration:var(--ui-animaton-speed);-webkit-transition-timing-function:ease;transition-timing-function:ease}:host(.display-tooltip) .icon-tooltip{display:block}:host(.show-tooltip) .icon-tooltip{opacity:1}:host(.large) .button-native{height:var(--spacing-comp-05);font-size:var(--font-size-lg) !important}:host(.button--primary-text-icon.large) .button-native{-webkit-padding-start:var(--spacing-comp-02);padding-inline-start:var(--spacing-comp-02);-webkit-padding-end:var(--spacing-comp-03);padding-inline-end:var(--spacing-comp-03)}:host(.button--primary-icon-only.large) .button-native{width:var(--spacing-comp-05);height:var(--spacing-comp-05)}:host(.button--secondary-text-icon.large) .button-native{-webkit-padding-start:var(--spacing-comp-02);padding-inline-start:var(--spacing-comp-02);-webkit-padding-end:var(--spacing-comp-03);padding-inline-end:var(--spacing-comp-03)}:host(.button--secondary-icon-only.large) .button-native{width:var(--spacing-comp-05);height:var(--spacing-comp-05)}:host(.button--tertiary.large) .button-native{height:var(--spacing-comp-05);width:var(--spacing-comp-05)}";

const GxgButton = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /*********************************
        PROPERTIES & STATE
        *********************************/
        /**
         * The prescence of this attribute makes the icon always black
         */
        this.alwaysBlack = false;
        /**
         * The state of the button, whether it is disabled or not
         */
        this.disabled = false;
        /**
         * The presence of this attribute makes the component full-width
         */
        this.fullWidth = false;
        /**
         * The prescence of this attribute turns the icon white
         */
        this.negative = false;
        /**
         * The kind of button
         */
        this.type = "primary-text-only";
        /**
         * The presence of this attribute lets the button styles be editable from outside of the component by referencing the "native-button" part.
         */
        this.buttonStylesEditable = false;
        this.mouseEnter = false;
        this.focusIn = false;
    }
    /*********************************
    METHODS
    *********************************/
    componentDidLoad() {
        // Set aria-label to host
        if (this.type === "primary-icon-only" ||
            this.type === "secondary-icon-only"
        //If button type is icon-only, aria-label must be provided in order to inform the user the button purpose.
        ) {
            if (this.el.querySelector(":scope > [slot='icon']")) {
                //Also, an icon must be provided, in order to know the button purpose.
                //The icon purpose is defined from the icon "type" property.
                const iconAriaLabel = this.el
                    .querySelector(":scope > [slot='icon']")
                    .getAttribute("type");
                this.el.setAttribute("aria-label", iconAriaLabel);
            }
        }
        //Set a part attribute to the button if buttonStylesEditable is true
        if (this.buttonStylesEditable) {
            this.el.shadowRoot
                .querySelector("button")
                .setAttribute("part", "native-button");
        }
    }
    emptyDiv() {
        return index.h("div", { style: { height: "20px" } });
        //This is a workaround I found for alligning vertically the buttons that have no icon, with the buttons that do have icons.
    }
    regularIcon() {
        if (this.type !== "primary-text-only" &&
            this.type !== "secondary-text-only" &&
            this.icon !== undefined) {
            return (index.h("gxg-icon", { type: this.icon, color: this.iconColor(), size: this.iconSize() }));
        }
    }
    iconSize() {
        let iSize;
        if (this.type === "secondary-icon-only" || this.type === "tertiary") {
            iSize = "regular";
        }
        else {
            iSize = "small";
        }
        return iSize;
    }
    iconColor() {
        let iColor;
        if (this.type.includes("primary")) {
            iColor = "negative";
            if (this.disabled) {
                iColor = "ondisabled";
            }
        }
        else if (this.type.includes("secondary")) {
            if (this.disabled) {
                iColor = "disabled";
            }
            else {
                if (this.mouseEnter) {
                    iColor = "primary-hover";
                }
                else {
                    if (this.focusIn) {
                        iColor = "primary-active";
                    }
                    else {
                        iColor = "primary-enabled";
                    }
                }
            }
        }
        else if (this.type.includes("tertiary")) {
            if (this.disabled) {
                iColor = "disabled";
            }
            else {
                if (this.alwaysBlack) {
                    iColor = "alwaysblack";
                }
                else if (this.negative) {
                    iColor = "negative";
                }
                else {
                    iColor = "onbackground";
                }
            }
        }
        return iColor;
    }
    clickHandler(e) {
        if (this.disabled) {
            e.preventDefault();
        }
    }
    handleFocus(focusEvent) {
        if (focusEvent.target !== this.el) {
            return;
        }
        this.button.focus();
    }
    onMouseEnter() {
        this.mouseEnter = true;
    }
    onMouseLeave() {
        this.mouseEnter = false;
    }
    onFocusIn() {
        this.focusIn = true;
        this.mouseEnter = false;
    }
    onFocusOut() {
        this.focusIn = false;
    }
    render() {
        return (index.h(index.Host, { role: "button", class: {
                button: true,
                "button--primary-text-only": this.type === "primary-text-only",
                "button--primary-text-icon": this.type === "primary-text-icon",
                "button--primary-icon-only": this.type === "primary-icon-only",
                "button--secondary-text-only": this.type === "secondary-text-only",
                "button--secondary-text-icon": this.type === "secondary-text-icon",
                "button--secondary-icon-only": this.type === "secondary-icon-only",
                "button--outlined": this.type === "outlined",
                "button--disabled": this.disabled === true,
                "button--tertiary": this.type === "tertiary",
                "button--fullwidth": this.fullWidth === true,
                large: store.state.large,
            }, onClick: this.clickHandler.bind(this), onMouseEnter: this.onMouseEnter.bind(this), onMouseLeave: this.onMouseLeave.bind(this), onfocusin: this.onFocusIn.bind(this), onfocusout: this.onFocusOut.bind(this) }, this.disabled ? index.h("div", { class: "disabled-layer" }) : null, index.h("button", { class: "button-native gxg-text-general", disabled: this.disabled === true, ref: (el) => (this.button = el), tabindex: "0" }, this.emptyDiv(), this.regularIcon(), this.type.includes("text") || this.type === "outlined" ? (index.h("span", { class: "text" }, index.h("slot", null))) : null)));
    }
    get el() { return index.getElement(this); }
};
GxgButton.style = buttonCss;

const iconCss$1 = "/*! normalize.css v8.0.1 | MIT License | github.com/necolas/normalize.css */html{line-height:1.15;-webkit-text-size-adjust:100%;}body{margin:0}main{display:block}h1{font-size:2em;margin:0.67em 0}hr{-webkit-box-sizing:content-box;box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace, monospace;font-size:1em;}a{background-color:transparent}abbr[title]{border-bottom:none;text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted;}b,strong{font-weight:bolder}code,kbd,samp{font-family:monospace, monospace;font-size:1em;}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-0.25em}sup{top:-0.5em}img{border-style:none}button,input,optgroup,select,textarea{font-family:inherit;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible}button,select{text-transform:none}button,[type=button],[type=reset],[type=submit]{-webkit-appearance:button}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText}fieldset{padding:0.35em 0.75em 0.625em}legend{-webkit-box-sizing:border-box;box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{vertical-align:baseline}textarea{overflow:auto}[type=checkbox],[type=radio]{-webkit-box-sizing:border-box;box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto}[type=search]{-webkit-appearance:textfield;outline-offset:-2px;}[type=search]::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit;}details{display:block}summary{display:list-item}template{display:none}[hidden]{display:none}:root{--ui-animaton-speed:0.2s}.gxg-title-01{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-title-01--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-title-02{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em}.gxg-title-02--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em;color:var(--color-on-primary)}.gxg-title-03{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-xs);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em}.gxg-title-03--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-xs);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em;color:var(--color-on-primary)}.gxg-title-04{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-title-04--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-title-05{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;line-height:1.556em}.gxg-title-05--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;line-height:1.556em;color:var(--color-on-primary)}.gxg-text{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-text--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-text--gray{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--gray-05)}.gxg-quote{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;font-style:italic}.gxg-quote--negative{color:var(--color-on-primary)}.gxg-link{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block}.gxg-link:hover{color:var(--color-primary-hover)}.gxg-link:active{color:var(--color-primary-active)}.gxg-link-gray{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block;color:var(--gray-04)}.gxg-link-gray:hover{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block;color:var(--gray-04);color:var(--gray-06)}.gxg-alert-error{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-error-dark);display:inline-block}.gxg-alert-warning{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-warning-dark);display:inline-block}.gxg-alert-success{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-success-dark);display:inline-block}.gxg-tab--disabled{color:var(--color-primary-disabled);pointer-events:none}.gxg-tab--disabled[disabled]{color:var(--color-primary-disabled);pointer-events:none}.gxg-label{font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em}.gxg-label:hover{color:var(--color-primary-hover)}.gxg-label:focud{color:var(--color-primary-active)}.gxg-label:active{color:var(--color-primary-active)}.gxg-label[disabled]{color:var(--color-primary-disabled)}.gxg-label--negative{color:var(--color-on-primary)}.gxg-label--negative[disabled]{color:var(--color-on-disabled)}.gxg-button-styles{font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em}:host{display:inline-block;line-height:0;height:20px;width:20px;display:-ms-inline-flexbox;display:inline-flex;-ms-flex-align:center;align-items:center;-ms-flex-pack:center;justify-content:center}";

/*********************************
CONSTANTS
*********************************/
const COLOR_MAPPINGS = {
    alwaysblack: "color-always-black",
    disabled: "color-primary-disabled",
    ondisabled: "color-on-disabled",
    error: "color-error-dark",
    negative: "color-on-primary",
    onbackground: "color-on-background",
    "primary-enabled": "color-primary-enabled",
    "primary-active": "color-primary-active",
    "primary-hover": "color-primary-hover",
    success: "color-success-dark",
    warning: "color-warning-dark",
};
const GxgIcon = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /**
         * The size of the icon. Possible values: regular, small.
         */
        this.size = "regular";
    }
    /*********************************
    METHODS
    *********************************/
    getSrcPath() {
        return index.getAssetPath(`icon-assets/${this.type}.svg`);
    }
    iconSize() {
        if (this.size === "regular") {
            return "16px";
        }
        else if (this.size === "small") {
            return "12px";
        }
    }
    render() {
        return (index.h(index.Host, null, index.h("ch-icon", { style: {
                "--icon-color": this.mapColorToCssVar(COLOR_MAPPINGS[this.color]),
                "--icon-size": this.iconSize(),
            }, "auto-color": this.color === "auto", src: this.getSrcPath() })));
    }
    mapColorToCssVar(color) {
        if (color) {
            return `var(--${color})`;
        }
        else {
            //default color
            return `var(--color-on-background)`;
        }
    }
    static get assetsDirs() { return ["icon-assets"]; }
    get element() { return index.getElement(this); }
};
GxgIcon.style = iconCss$1;

const modalCss = "/*! normalize.css v8.0.1 | MIT License | github.com/necolas/normalize.css */html{line-height:1.15;-webkit-text-size-adjust:100%;}body{margin:0}main{display:block}h1{font-size:2em;margin:0.67em 0}hr{-webkit-box-sizing:content-box;box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace, monospace;font-size:1em;}a{background-color:transparent}abbr[title]{border-bottom:none;text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted;}b,strong{font-weight:bolder}code,kbd,samp{font-family:monospace, monospace;font-size:1em;}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-0.25em}sup{top:-0.5em}img{border-style:none}button,input,optgroup,select,textarea{font-family:inherit;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible}button,select{text-transform:none}button,[type=button],[type=reset],[type=submit]{-webkit-appearance:button}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText}fieldset{padding:0.35em 0.75em 0.625em}legend{-webkit-box-sizing:border-box;box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{vertical-align:baseline}textarea{overflow:auto}[type=checkbox],[type=radio]{-webkit-box-sizing:border-box;box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto}[type=search]{-webkit-appearance:textfield;outline-offset:-2px;}[type=search]::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit;}details{display:block}summary{display:list-item}template{display:none}[hidden]{display:none}:root{--ui-animaton-speed:0.2s}.gxg-title-01{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-title-01--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-title-02{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em}.gxg-title-02--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em;color:var(--color-on-primary)}.gxg-title-03{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-xs);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em}.gxg-title-03--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-xs);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em;color:var(--color-on-primary)}.gxg-title-04{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-title-04--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-title-05{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;line-height:1.556em}.gxg-title-05--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;line-height:1.556em;color:var(--color-on-primary)}.gxg-text{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-text--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-text--gray{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--gray-05)}.gxg-quote{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;font-style:italic}.gxg-quote--negative{color:var(--color-on-primary)}.gxg-link{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block}.gxg-link:hover{color:var(--color-primary-hover)}.gxg-link:active{color:var(--color-primary-active)}.gxg-link-gray{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block;color:var(--gray-04)}.gxg-link-gray:hover{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block;color:var(--gray-04);color:var(--gray-06)}.gxg-alert-error{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-error-dark);display:inline-block}.gxg-alert-warning{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-warning-dark);display:inline-block}.gxg-alert-success{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-success-dark);display:inline-block}.gxg-tab--disabled{color:var(--color-primary-disabled);pointer-events:none}.gxg-tab--disabled[disabled]{color:var(--color-primary-disabled);pointer-events:none}.gxg-label{font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em}.gxg-label:hover{color:var(--color-primary-hover)}.gxg-label:focud{color:var(--color-primary-active)}.gxg-label:active{color:var(--color-primary-active)}.gxg-label[disabled]{color:var(--color-primary-disabled)}.gxg-label--negative{color:var(--color-on-primary)}.gxg-label--negative[disabled]{color:var(--color-on-disabled)}.gxg-button-styles{font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em}:host .modal{display:-ms-flexbox;display:flex;-ms-flex-direction:column;flex-direction:column;opacity:0;background:var(--color-on-primary);-webkit-box-shadow:var(--box-shadow-03);box-shadow:var(--box-shadow-03);border-radius:var(--border-radius-md);position:absolute;left:50%;top:50%;margin-top:30px;-webkit-transform:translateY(-50%) translateX(-50%);transform:translateY(-50%) translateX(-50%);font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em}:host .modal--visible{opacity:1;margin-top:0}:host .modal--transition{-webkit-transition-property:opacity, margin-top;transition-property:opacity, margin-top;-webkit-transition-duration:var(--ui-animaton-speed);transition-duration:var(--ui-animaton-speed);-webkit-transition-timing-function:ease;transition-timing-function:ease}:host .modal__header{display:-ms-flexbox;display:flex;-ms-flex-align:center;align-items:center;-ms-flex-pack:justify;justify-content:space-between}:host .modal__header__title{font-weight:var(--font-weight-bold)}:host .modal__container{padding:var(--spacing-comp-04) 0}:host .modal__footer{display:-ms-flexbox;display:flex}:host .modal__footer ::slotted([slot=footer]) *{margin-left:var(--spacing-comp-02);margin-right:var(--spacing-comp-02)}:host([padding=\"0\"]) .modal{padding:0}:host([padding=xs]) .modal{padding:var(--spacing-comp-01)}:host([padding=s]) .modal{padding:var(--spacing-comp-02)}:host([padding=m]) .modal{padding:var(--spacing-comp-03)}:host([padding=l]) .modal{padding:var(--spacing-comp-04)}:host([padding=xl]) .modal{padding:var(--spacing-comp-05)}:host([padding=xxl]) .modal{padding:var(--spacing-comp-06)}:host([padding=xxxl]) .modal{padding:var(--spacing-comp-07)}:host .layer{position:absolute;width:100%;height:100%;top:0;left:0;background-color:black;opacity:0;-webkit-transition-property:opacity;transition-property:opacity;-webkit-transition-duration:var(--ui-animaton-speed);transition-duration:var(--ui-animaton-speed);-webkit-transition-timing-function:ease;transition-timing-function:ease}:host .layer--visible{opacity:0.25}:host(.footer-justify-end) .modal__footer{-ms-flex-pack:end;justify-content:flex-end}:host(.footer-justify-space-between) .modal__footer{-ms-flex-pack:justify;justify-content:space-between}";

const GxgModal = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /*The accordion padding (internal spacing)*/
        this.padding = "s";
        /**
         * The footer justify content type
         */
        this.footerJustifyContent = "flex-end";
        /**
         * The modal width
         */
        this.width = "300px";
        /**
         * Wether the modal is visible or not
         */
        this.visible = false;
        /**
         * The z-index value of the modal
         */
        this.zIndex = "100";
        /**
         * The presence of this attribute removes the sound that plays when the modal appears
         */
        this.silent = false;
        this.layerVisible = false;
        this.modalVisible = false;
        this.modalTransition = false;
    }
    componentDidLoad() {
        this.el.style.display = "block";
    }
    closeModal() {
        this.layerVisible = false;
        this.modalVisible = false;
        setTimeout(function () {
            this.visible = false;
            this.modalTransition = false;
        }.bind(this), 250);
    }
    watchVisibleHandler() {
        if (this.visible === true) {
            setTimeout(function () {
                this.modalTransition = true;
                setTimeout(function () {
                    this.layerVisible = true;
                    this.modalVisible = true;
                }.bind(this), 50);
            }.bind(this), 50);
        }
    }
    modalHidden() {
        if (this.visible) {
            return "false";
        }
        else {
            return "true";
        }
    }
    render() {
        return this.visible === true ? (index.h(index.Host, { role: "dialog", "aria-hidden": this.modalHidden(), class: {
                "footer-justify-end": this.footerJustifyContent === "flex-end",
                "footer-justify-space-between": this.footerJustifyContent === "space-between",
            } }, index.h("div", { class: {
                modal: true,
                "modal--visible": this.modalVisible,
                "modal--transition": this.modalTransition,
            }, style: { width: this.width, "z-index": this.zIndex + 1 } }, index.h("header", { class: "modal__header" }, index.h("span", { class: "modal__header__title" }, this.modalTitle), index.h("gxg-button", { icon: "gemini-tools/close", type: "secondary-icon-only", onClick: this.closeModal.bind(this) })), index.h("div", { class: "modal__container" }, index.h("slot", null)), index.h("footer", { class: "modal__footer" }, index.h("slot", { name: "footer" }))), index.h("div", { class: {
                layer: true,
                "layer--visible": this.layerVisible,
            }, style: { "z-index": this.zIndex } }))) : null;
    }
    get el() { return index.getElement(this); }
    static get watchers() { return {
        "visible": ["watchVisibleHandler"]
    }; }
};
GxgModal.style = modalCss;

const spacerOneCss = "/*! normalize.css v8.0.1 | MIT License | github.com/necolas/normalize.css */html{line-height:1.15;-webkit-text-size-adjust:100%;}body{margin:0}main{display:block}h1{font-size:2em;margin:0.67em 0}hr{-webkit-box-sizing:content-box;box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace, monospace;font-size:1em;}a{background-color:transparent}abbr[title]{border-bottom:none;text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted;}b,strong{font-weight:bolder}code,kbd,samp{font-family:monospace, monospace;font-size:1em;}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-0.25em}sup{top:-0.5em}img{border-style:none}button,input,optgroup,select,textarea{font-family:inherit;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible}button,select{text-transform:none}button,[type=button],[type=reset],[type=submit]{-webkit-appearance:button}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText}fieldset{padding:0.35em 0.75em 0.625em}legend{-webkit-box-sizing:border-box;box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{vertical-align:baseline}textarea{overflow:auto}[type=checkbox],[type=radio]{-webkit-box-sizing:border-box;box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto}[type=search]{-webkit-appearance:textfield;outline-offset:-2px;}[type=search]::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit;}details{display:block}summary{display:list-item}template{display:none}[hidden]{display:none}:root{--ui-animaton-speed:0.2s}.gxg-title-01{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-title-01--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-title-02{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em}.gxg-title-02--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-bold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em;color:var(--color-on-primary)}.gxg-title-03{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-xs);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em}.gxg-title-03--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-xs);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;text-transform:uppercase;line-height:1.556em;color:var(--color-on-primary)}.gxg-title-04{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-title-04--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-md);letter-spacing:var(--letter-spacing-md);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-title-05{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;line-height:1.556em}.gxg-title-05--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-sm);color:var(--color-on-background);text-align:start;line-height:1.556em;color:var(--color-on-primary)}.gxg-text{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em}.gxg-text--negative{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-on-primary)}.gxg-text--gray{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--gray-05)}.gxg-quote{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;font-style:italic}.gxg-quote--negative{color:var(--color-on-primary)}.gxg-link{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block}.gxg-link:hover{color:var(--color-primary-hover)}.gxg-link:active{color:var(--color-primary-active)}.gxg-link-gray{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block;color:var(--gray-04)}.gxg-link-gray:hover{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-primary);text-decoration:underline;cursor:pointer;display:inline-block;color:var(--gray-04);color:var(--gray-06)}.gxg-alert-error{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-error-dark);display:inline-block}.gxg-alert-warning{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-warning-dark);display:inline-block}.gxg-alert-success{font-family:var(--font-family-primary);font-weight:var(--font-weight-regular);font-size:var(--font-size-sm);letter-spacing:var(--letter-spacing-xs);color:var(--color-on-background);text-align:start;line-height:1.455em;color:var(--color-success-dark);display:inline-block}.gxg-tab--disabled{color:var(--color-primary-disabled);pointer-events:none}.gxg-tab--disabled[disabled]{color:var(--color-primary-disabled);pointer-events:none}.gxg-label{font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em}.gxg-label:hover{color:var(--color-primary-hover)}.gxg-label:focud{color:var(--color-primary-active)}.gxg-label:active{color:var(--color-primary-active)}.gxg-label[disabled]{color:var(--color-primary-disabled)}.gxg-label--negative{color:var(--color-on-primary)}.gxg-label--negative[disabled]{color:var(--color-on-disabled)}.gxg-button-styles{font-family:var(--font-family-primary) !important;font-weight:var(--font-weight-semibold);font-size:var(--font-size-sm) !important;letter-spacing:var(--letter-spacing-xs);color:var(--color-primary-enabled);text-align:center;line-height:1.455em}:host{display:inline-block;margin-bottom:0 !important;margin-right:0 !important}:host(.xs){height:var(--spacing-lay-xs);width:var(--spacing-lay-xs)}:host(.s){height:var(--spacing-lay-s);width:var(--spacing-lay-s)}:host(.m){height:var(--spacing-lay-m);width:var(--spacing-lay-m)}:host(.l){height:var(--spacing-lay-l);width:var(--spacing-lay-l)}:host(.xl){height:var(--spacing-lay-xl);width:var(--spacing-lay-xl)}";

const GxgSpacerOne = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    render() {
        return (index.h(index.Host, { class: {
                xs: this.space === "xs",
                s: this.space === "s",
                m: this.space === "m",
                l: this.space === "l",
                xl: this.space === "xl"
            } }));
    }
};
GxgSpacerOne.style = spacerOneCss;

exports.ch_icon = ChIcon;
exports.gxg_button = GxgButton;
exports.gxg_icon = GxgIcon;
exports.gxg_modal = GxgModal;
exports.gxg_spacer_one = GxgSpacerOne;
